/**
 * Copyright (c) 2016-2024 Governikus GmbH & Co. KG, Germany
 */

/*!
 * \brief Generic implementation of the controller for retrieving and presenting diagnosis info.
 */


#include "DiagnosisController.h"


using namespace governikus;


void DiagnosisController::getPcscInfo(QList<DiagnosisContext::ComponentInfo>& pComponents,
		QList<DiagnosisContext::ComponentInfo>& pDrivers)
{
	Q_UNUSED(pComponents)
	Q_UNUSED(pDrivers)
}
